Transport class abstract

Abstract base class for all transport implementations

Implementers

Constructors

Transport()

Properties

connected → bool
Whether this transport is currently connected
no setter
connectionStateStream → Stream<bool>
Stream of connection state changes
no setter
errorStream → Stream<FayeError>
Stream of errors
no setter
hashCode → int
The hash code for this object.
no setterinherited
messageStream → Stream<Map<String, dynamic>>
Stream of messages received from the transport
no setter
name → String
Transport name
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statistics → Map<String, dynamic>
Get transport statistics
no setter
supported → bool
Whether this transport is supported
no setter
timeout ↔ int
Connection timeout in seconds
getter/setter pair

Methods

close() → Future<void>
Close the transport
connect(String url, {Map<String, String>? headers}) → Future<void>
Connect to the server
disconnect() → Future<void>
Disconnect from the server
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Map<String, dynamic> message) → Future<void>
Send a message to the server
sendBatch(List<Map<String, dynamic>> messages) → Future<void>
Send multiple messages to the server
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited